#
# spec file for package rasdaemon
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rasdaemon
Version:        0.6.7.18.git+7ccf12f
Release:        150500.7.3.2
Summary:        Utility to receive RAS error tracings
License:        GPL-2.0-only
Group:          Hardware/Other
URL:            http://git.infradead.org/users/mchehab/rasdaemon.git
Source:         %{name}-%{version}.tar.xz
Patch0:         rasdaemon-Update-SMCA-bank-error-descriptions.patch
Patch2:         rasdaemon-Handle-reassigned-bit-definitions-for-CS-SMCA.patch
Patch3:         rasdaemon-Add-support-for-post-processing-MCA-errors.patch
Patch4:         rasdaemon-Add-new-MA_LLC-USR_DP-and-USR_CP-bank-types.patch
Patch5:         rasdaemon-Handle-reassigned-bit-definitions-for-UMC-bank.patch
Patch6:         rasdaemon-Identify-the-DIe-Number-in-multidie-system.patch
Patch7:         rasdaemon-Fix-SMCA-bank-type-decoding.patch
Patch8:         rasdaemon-Fix-poll-on-per_cpu-trace_pipe_raw-blocks-indefinitely.patch
Patch9:         rasdaemon-Add-error-decoding-for-MCA_CTL_SMU-extended-bits.patch
PAtch10:        rasdaemon-mce-amd-smca-Optimizing-decoding-of-MCA_CTL_SMU-bits.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-devel
BuildRequires:  libtool
BuildRequires:  sqlite3-devel
Requires(pre):  %fillup_prereq
Requires:       perl-DBD-SQLite
%{?systemd_ordering}
%ifnarch s390x
Requires:       dmidecode
%endif

%description
rasdaemon is a RAS (Reliability, Availability and Serviceability) logging tool.
It currently records memory errors, using the EDAC tracing events.
EDAC is drivers in the Linux kernel that handle detection of ECC errors
from memory controllers for most chipsets on i386 and x86_64 architectures.
EDAC drivers for other architectures like arm also exists.
This userspace component consists of an init script which makes sure
EDAC drivers and DIMM labels are loaded at system startup, as well as
an utility for reporting current error counts from the EDAC sysfs files.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -fvi
%configure --enable-all --with-sysconfdefdir=%{_sysconfdir}/sysconfig
CFLAGS="%{optflags}" make %{?_smp_mflags} V=1

%install
%make_install
make install DESTDIR=%{buildroot}
install -D -p -m 0644 misc/rasdaemon.service %{buildroot}%{_unitdir}/rasdaemon.service
install -D -p -m 0644 misc/ras-mc-ctl.service %{buildroot}%{_unitdir}/ras-mc-ctl.service
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcrasdaemon
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcras-mc-ctl
rm INSTALL %{buildroot}/usr/include/*.h
mkdir -p %{buildroot}%{_localstatedir}/lib/rasdaemon
mkdir -p %{buildroot}%{_fillupdir}
mv %{buildroot}%{_sysconfdir}/sysconfig/rasdaemon %{buildroot}/%{_fillupdir}/sysconfig.rasdaemon

%pre
%service_add_pre rasdaemon.service ras-mc-ctl.service

%post
%fillup_only
%service_add_post rasdaemon.service ras-mc-ctl.service

%preun
%service_del_preun rasdaemon.service ras-mc-ctl.service

%postun
%service_del_postun rasdaemon.service ras-mc-ctl.service

%files
%license COPYING
%doc AUTHORS ChangeLog README TODO
%{_sbindir}/rasdaemon
%{_sbindir}/ras-mc-ctl
%{_sbindir}/rcrasdaemon
%{_sbindir}/rcras-mc-ctl
%{_mandir}/*/*
%{_unitdir}/*.service
%dir %{_sysconfdir}/ras
%dir %{_localstatedir}/lib/rasdaemon
%ghost %{_localstatedir}/lib/rasdaemon/ras-mc_event.db
%attr (644,root,root) %{_fillupdir}/sysconfig.rasdaemon

%changelog
* Fri Jul 19 2024 aschnell@suse.com
- bsc#1226114
  * rasdaemon: Fix poll() on per_cpu trace_pipe_raw blocks indefinitely
  * rasdaemon: Add error decoding for MCA_CTL_SMU extended bits
  * rasdaemon: mce-amd-smca: Optimizing decoding of MCA_CTL_SMU bits
  A rasdaemon-Fix-poll-on-per_cpu-trace_pipe_raw-blocks-indefinitely.patch
  A rasdaemon-Add-error-decoding-for-MCA_CTL_SMU-extended-bits.patch
  A rasdaemon-mce-amd-smca-Optimizing-decoding-of-MCA_CTL_SMU-bits.patch
* Sat Feb 17 2024 trenn@suse.de
- jsc#PED-7633
  * rasdaemon: Fix SMCA bank type decoding
  * rasdaemon: Identify the DIe Number in multidie system
  * rasdaemon: Handle reassigned bit definitions for UMC bank
  * rasdaemon: Add new MA_LLC, USR_DP, and USR_CP bank types.
  * rasdaemon: Add support for post-processing MCA errors
  * rasdaemon: Handle reassigned bit definitions for CS SMCA
  * rasdaemon: Update SMCA bank error descriptions
  A rasdaemon-Update-SMCA-bank-error-descriptions.patch
  A rasdaemon-Handle-reassigned-bit-definitions-for-CS-SMCA.patch
  A rasdaemon-Add-support-for-post-processing-MCA-errors.patch
  A rasdaemon-Add-new-MA_LLC-USR_DP-and-USR_CP-bank-types.patch
  A rasdaemon-Handle-reassigned-bit-definitions-for-UMC-bank.patch
  A rasdaemon-Identify-the-DIe-Number-in-multidie-system.patch
  A rasdaemon-Fix-SMCA-bank-type-decoding.patch
* Thu Oct 14 2021 trenn@suse.de
- Fix systemd service file pointing to fillup file instead of
  /etc/sysconfig/rasdaemon
* Tue Oct 12 2021 trenn@suse.de
- Add new /etc/sysconfig/rasdaemon config via fillup (bsc#1190668)
* Tue Aug 31 2021 trenn@suse.de
- Update to version 0.6.7.18.git+7ccf12f:
  * labels/supermicro: added Supermicro X11SCW
  * labels/supermicro: added Supermicro X10DRL, X11SPM
  * labels/supermicro: added Supermicro X11SCA(-F)
  * labels/supermicro: added Supermicro B1DRi
  * labels/supermicro: added Supermicro X11DDW-NT(-L)
  * labels/supermicro: added Supermicro X10DRI(-T)
  * labels/supermicro: supermicro db syntax
  * labels/supermicro: added x11dph-i labels
  * rasdaemon: Support MCE for AMD CPU family 19h
  * rasdaemon: Enumerate memory on noncpu nodes
  * rasdaemon: set SMCA maximum number of banks to 64
  * rasdaemon: Add new SMCA bank types with error decoding
  * configure.ac: fix SYSCONFDEFDIR default value
  * Add error handling for Ampere-specific errors.
- Make git hash in version better visable .git+<githash>
* Wed Aug 11 2021 trenn@suse.de
- Use %%{?systemd_ordering} instead of %%{?systemd_requires}
* Fri Jul  9 2021 trenn@suse.de
- Enable ppc64le build
- Enhance _service magic
- Update to version 0.6.7.4.gdda7d95:
  * Add support for multi-arch builds
  * rasdaemon.spec.in: don't install _sharedstatedir
  * rasdaemon: Add Ice Lake and Sapphire Rapids MSCOD values
  * rasdaemon: fix build error in register_ns_ev_decoder if the sqlite3 is not enabled
  * rasdaemon: Modify confiure.ac for Hisilicon Kunpeng errors
  * rasdaemon: ras-mc-ctl: Add support for HiSilicon Kunpeng9xx common errors
  * rasdaemon: ras-mc-ctl: Add support for HiSilicon Kunpeng920 errors
  * rasdaemon: ras-mc-ctl: Add support for the vendor-specific errors
  * rasdaemon: ras-mc-ctl: Add memory failure events
  * rasdaemon: ras-mc-ctl: Modify ARM processor error summary log
  * rasdaemon: add support for memory_failure events
  * ras-record: Create RASSTATEDIR at runtime instead of install time
  * add labels for A2SDi-8C+-HLN4F
  * Added label for ASUS PRIME X570-PRO
  * Add code to decode Ampere specific error
  * rasdaemon: fix memory leak in parse_ras_data
  * Fix ras-mc-ctl script.
  * add Supermicro X10SRA-F and H8DGU.
  * ras-page-isolation: page which is PAGE_OFFLINE_FAILED can be offlined again
  * ras-page-isolation: do_page_offline always considers page offline was successful
  * Fix problem from make dist-rpm
  * rasdaemon: Add 8 channel decoding for SMCA systems
  * rasdaemon: Fix error print
  * Create SYSCONFDEFDIR configure parameter
  * rasdaemon: ras-mc-ctl: Add ARM processor error information
  * rasdaemon: add support for hisilicon common section decoder
  * rasdaemon: Add error decoding for new SMCA Load Store bank type
  * rasdaemon: Fix "ignoring return value" build warning.
  * Match rankX in ras-mc-ctl
  * added label for A2SDi-8C-HLN4F
  * ras-mc-ctl: PCIe AER: display PCIe dev name
  * rasdaemon: add support for memory Corrected Error predictive failure analysis
  * rasdaemon: add rbtree support for page record
  * rasdaemon: fix the issue that non standard decoder can't work in pthread way
  * rasdaemon: add support of l3tag and l3data in hip08 OEM format2
* Wed Apr 29 2020 trenn@suse.de
- Let squlite create devlink_event and other tables via configure option
  bsc#1170016, bsc#1170014
* Thu Feb  6 2020 trenn@suse.de
- Update to version 0.6.5+git20200205.3dca35f
- bsc#1162524
  Mainline commits:
  3a4fc059d58d876733d5fd9098b6be9e2a9034d8
  a16ca0711001957ee98f2c124abce0fa1f801529
  which are required for bsc#1162524:
  rasdaemon update with support for AMD scalable MCA and cnamburu-naples-support
* Thu Aug 23 2018 mpluskal@suse.com
- Update to version 0.6.2:
  * Bump to version 0.6.2
  * INSTALL: update it from auto-generated data
  * ChangeLog: Reorder to place new stuff at the beginning
  * rasdaemon: ras-mc-ctl: add option to show error counts
  * mce-amd-k8: be sure to not go past error_msg buffer
  * ras-report: avoid copying after addr.sun_path
  * mce-intel-*: fix a warning when using FIELD(<num>, NULL)
  * rasdaemon: use separate string array for error status
  * rasdaemon: fix PCIe AER error type
* Fri Jun 15 2018 mpluskal@suse.com
- Update to version 0.6.1:
  * Bump version to 0.6.1
  * rasdaemon: Update DIMM labels for 2-socket servers
  * rasdaemon: Add Skylake Xeon MSCOD values
  * rasdaemon: ARM: fully initialize ras_arm_event
  * Update my email
  * mce-intel-p4-p6: prevent build errors with -Werror=format-security
* Thu Apr  5 2018 josef.moellers@suse.com
- Enabled arm and non-standard.
  [bsc#1086520, FATE#323658]
* Wed Jan 17 2018 josef.moellers@suse.com
- Do not require dmidecode on s390x and ppc64le, it does not
  exist there!
  [bsc#1071830]
* Tue Nov 21 2017 eich@suse.com
- Update to version 0.6.0:
  * rasdaemon: Update DIMM labels for Intel Skylake servers
  * rasdaemon:add support for non-standard error decoder
  * rasdaemon:add support for Hisilicon non-standard error decoder
  * configure.ac: show if Hisilicon error report are enabled
  * rasdaemon: add support for ARM events
  * configure.ac: display if ARM error report is enabled
  * rasdaemon: update bugs report information
  * Makefile: add new rasdaemon headers
  * rasdaemon.spec: add other --enable options
  * Bump to version 0.6.0
  (FATE#323162).
* Fri Jun  9 2017 fschnizlein@suse.com
- Update to version 0.5.9:
  * Update it to point to the new repository
  * configure.ac: report enabled features
  * rasdaemon: Update DIMM labels for Dell Servers
  * rasdaemon: add Knights Mill model
  * rasdaemon.spec.in: update it to reflect current needs
* Mon Apr 10 2017 mpluskal@suse.com
- Switch to _service as fedorahosted is retired
- Update project url
- Use macro for systemd dependencies
- Make building more verbose
- Install provided labels for dell
* Tue May 31 2016 fvogt@suse.com
- Update to 0.5.8, obsoleted patches:
  - broadwell_de_mscod.patch
  - broadwell_ep_ex_mscod.patch
* Tue May 31 2016 trenn@suse.de
- Add MSCOD values for broadwell de/ep/ex processors
  * Add broadwell_de_mscod.patch
  * Add broadwell_ep_ex_mscod.patch
* Mon Mar  7 2016 fvogt@suse.com
- Run spec-cleaner: - Change Group and copyright notice
* Mon Mar  7 2016 trenn@suse.de
- Update to version 0.5.7 (including Knights Landing CPU support, fate#319513)
* Fri Nov 27 2015 fvogt@suse.com
- Use provided .tar.xz directly instead of generating one via tar_scm
* Wed Nov 25 2015 trenn@suse.de
- Fix upper case letter issues on requires on package perl-DBD-SQLite
- Create /var/lib/rasdaemon for db file creation at runtime
* Fri Nov  6 2015 fvogt@suse.com
- Disable _service and run manually
* Tue Nov  3 2015 fvogt@suse.com
- Initial commit from git
